@@ -2,7 +2,7 @@ import objc
 from Foundation import *
 from AppKit import *
 from PyObjCTools import AppHelper
-import ofxclient.server, webbrowser, ofxclient
+import ofxclient.server, webbrowser, ofxclient, os, ofxclient.settings, time
 
 class MyApp(NSApplication):
 
@@ -16,50 +16,70 @@ class MyApp(NSApplication):
         self.statusitem.setImage_(self.icon)
         self.statusitem.setHighlightMode_(True)
 
+        #add menu to statusitem
+        self.statusitem.setToolTip_('OFX Client')
+        self.updateMenu()
+
+        t = NSThread.alloc().initWithTarget_selector_object_(self,self.runServer, None)
+        t.start()
+
+        c = NSThread.alloc().initWithTarget_selector_object_(self,self.configWatcher, None)
+        c.start()
+
+    def configWatcher(self):
+        lastRefresh = None
+        while 1:
+            modifiedOn = os.stat(ofxclient.settings.CONFFILE).st_mtime
+            if lastRefresh is None or modifiedOn > lastRefresh:
+                lastRefresh = modifiedOn
+                self.updateMenu()
+            time.sleep(1)
+
+
+    def updateMenu(self):
+        self.statusitem.setMenu_(None)
+        self.statusitem.setMenu_(self.makeMenu())
+
+    def makeMenu(self):
         #make the menu
-        self.menubarMenu = NSMenu.alloc().init()
+        menubarMenu = NSMenu.alloc().init()
 
         unsorted = [ i.__json__() for i in ofxclient.Account.list() ]
         accounts = sorted(unsorted,key=lambda a: str(a['long_description']).lower())
 
-        self.accountsMain = NSMenuItem.alloc().init()
-        self.accountsMain.setTitle_('Download')
+        accountsMain = NSMenuItem.alloc().init()
+        accountsMain.setTitle_('Download')
         if not accounts:
-            self.accountsMain.setEnabled_(False)
+            accountsMain.setEnabled_(False)
 
             error = NSMenuItem.alloc().init()
             error.setTitle_('No Accounts Configured')
             error.setEnabled_(False)
-            self.menubarMenu.addItem_(error)
-            self.menubarMenu.addItem_(NSMenuItem.separatorItem())
+            menubarMenu.addItem_(error)
+            menubarMenu.addItem_(NSMenuItem.separatorItem())
 
 
         if accounts:
-            self.accountsSubMenu = NSMenu.alloc().init()
+            accountsSubMenu = NSMenu.alloc().init()
             for a in accounts:
                 item = NSMenuItem.alloc().initWithTitle_action_keyEquivalent_(a['long_description'],'download:','')
                 item.setRepresentedObject_(a['guid'])
-                self.accountsSubMenu.addItem_(item)
-            self.accountsMain.setSubmenu_(self.accountsSubMenu)
+                accountsSubMenu.addItem_(item)
+            accountsMain.setSubmenu_(accountsSubMenu)
 
-        self.menubarMenu.addItem_(self.accountsMain)
+        menubarMenu.addItem_(accountsMain)
 
-        self.menubarMenu.addItem_(NSMenuItem.separatorItem())
+        menubarMenu.addItem_(NSMenuItem.separatorItem())
 
-        self.menuItem = NSMenuItem.alloc().initWithTitle_action_keyEquivalent_('Configure...', 'open:', '')
-        self.menubarMenu.addItem_(self.menuItem)
+        menuItem = NSMenuItem.alloc().initWithTitle_action_keyEquivalent_('Configure...', 'open:', '')
+        menubarMenu.addItem_(menuItem)
 
-        self.menubarMenu.addItem_(NSMenuItem.separatorItem())
+        menubarMenu.addItem_(NSMenuItem.separatorItem())
 
-        self.quit = NSMenuItem.alloc().initWithTitle_action_keyEquivalent_('Quit', 'terminate:', '')
-        self.menubarMenu.addItem_(self.quit)
+        quit = NSMenuItem.alloc().initWithTitle_action_keyEquivalent_('Quit', 'terminate:', '')
+        menubarMenu.addItem_(quit)
+        return menubarMenu
 
-        #add menu to statusitem
-        self.statusitem.setMenu_(self.menubarMenu)
-        self.statusitem.setToolTip_('OFX Client')
-
-        t = NSThread.alloc().initWithTarget_selector_object_(self,self.runServer, None)
-        t.start()
 
     def runServer(self):
         pool = NSAutoreleasePool.alloc().init()
